import turbogears
from turbogears import controllers, expose
from turbogears import flash, redirect, url
from paraxip.gateway_gui import extjs
from pstnconfig import model
from operator import itemgetter
import simplejson
import os

import logging
log = logging.getLogger("pstnconfig.controllers")

class BoardsController(controllers.Controller):
#################################################
#                                               #
# Boards methods (Add/delete/get/save)          #
#                                               #
#################################################
  ##########################################################################
  @expose()
  def addBoardFromEditor (self, **data):
    """Adds a board to the actual config from the editor"""
    log.info("Adding board: %s" % data)

    boardData = simplejson.loads(data['newBoardData'])
    boardModel = boardData['boardModel']
    config = model.currentConfig
    assert model.boardsModelInfo.has_key(boardModel)
    boardModelInfo = model.boardsModelInfo[boardModel]
    nextWanpipe = model.getNextWanpipe(config)

    if boardModelInfo['type'] == 'digital':
      model.addSangomaDigitalBoard(config,
        boardModel=boardModel,
        boardID=model.getNextBoardID(config),
        starting_wanpipe=nextWanpipe)
    elif boardModelInfo['type'] == 'analog':
      model.addSangomaAnalogBoard(config,
        boardModel=boardModel,
        boardID=model.getNextBoardID(config),
        wanpipe=nextWanpipe,
        numInterfaces=boardData['interfaceNum'])
    elif boardModelInfo['type'] == 'virtual_digital':
      model.addSangomaVirtualDigitalBoard(config,
        boardID=model.getNextBoardID(config),
        numInterfaces=boardData['interfaceNum'])
    else:
      assert 'Unsupported board model type'


    model.writeCurrentConfigToFile()
    return(str(extjs.FormActionSubmitResponse(success=True)))

  ##########################################################################
  @expose()
  def deleteBoardFromEditor (self, **data):
    """Delete a board to the actual config from the editor"""
    log.info("Deleting board: %s" % data)

    boardsData = simplejson.loads(data['boards'])
    config = model.currentConfig

    for boardInfo in boardsData:
      model.deleteBoard(config, boardInfo['id'])

    #save the config afterward
    model.writeCurrentConfigToFile()
    
    return(str(extjs.FormActionSubmitResponse(success=True)))

  ##########################################################################
  # Returns a dictionary exposing the values of the board corresponding to 
  # the passed id.
  # The fields to be exposed to the user are:
  #   - the id of the board entered in the config file
  #   - registered id (hidden field).
  #   - The display name of the board
  #   - The type of the board (digital in that case)
  #   - The model of the board (A101,A102,A104 or A108)
  #   - The number of interface for this board
  @expose() # Ext.form.Action.load - expects JSON
  def getFrmDigitalBoardData(self, id):
    log.info("Getting board data for board id: %s" % id)
    board = model.getObjectFromEditorId(id)
    boardModel = board.get_model() #get the board model
    data = {
      'id': board.get_ID(),
      'nodeId': id,
      'displayName': board.get_displayName(),
      'type': model.boardsModelInfo[boardModel]['type'],
      'model': boardModel,
      'numInterfaces': model.boardsModelInfo[boardModel]['numInterfaces'],
    }             
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Returns a dictionary exposing the values of the board corresponding to 
  # the passed id.
  # The fields to be exposed to the user are:
  #   - the id of the board entered in the config file
  #   - registered id (hidden field).
  #   - The display name of the board
  #   - The type of the board (analog in that case)
  #   - The model of the board (A200)
  #   - The number of interfaces
  #   - The wanpipe number
  @expose() # Ext.form.Action.load - expects JSON
  def getFrmAnalogBoardData(self, id):
    log.info("Getting board data for board id: %s" % id)
    board = model.getObjectFromEditorId(id)
    boardModel = board.get_model() #get the board model
    data = {
      'id': board.get_ID(),
      'nodeId': id,
      'displayName': board.get_displayName(),
      'type': model.boardsModelInfo[boardModel]['type'],
      'model': boardModel,
      'numInterfaces': len(board.get_interface()),
      'wanpipe': board.get_wanpipe()
    }             
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Returns a dictionary exposing the values of the virtual digital board 
  #   corresponding to the passed id.
  # The fields to be exposed to the user are:
  #   - the id of the board entered in the config file
  #   - registered id (hidden field).
  #   - The display name of the board
  #   - The type of the board (analog in that case)
  #   - The model of the board (A200)
  #   - The number of interfaces
  @expose() # Ext.form.Action.load - expects JSON
  def getFrmVirtualDigitalBoardData(self, id):
    log.info("Getting board data for board id: %s" % id)
    board = model.getObjectFromEditorId(id)
    boardModel = board.get_model() #get the board model
    data = {
      'id': board.get_ID(),
      'nodeId': id,
      'displayName': board.get_displayName(),
      'type': model.boardsModelInfo[boardModel]['type'],
      'model': boardModel,
      'numInterfaces': len(board.get_interface())
    }             
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Saves the modified informations of the board.
  # Editable values are:
  #   - displayName
  #   - wanpipe if it is an analog board
  @expose()
  def saveBoards (self, **data):
    """Saves the modifications to a board entered by the user in the editor"""

    log.info("Saving board informations with data: %s" % data)

    #Decode received data
    boardData = simplejson.loads(data['boardInfo'])

    #Retrieve the corresponding instance for the board id
    board = model.getObjectFromEditorId(boardData['nodeId'])

    #Reassign modified values    
    model.saveAttributes(board,boardData)

    #save the config afterward
    model.writeCurrentConfigToFile()

    return(str(extjs.FormActionSubmitResponse(success=True)))

  ##########################################################################
  # Returns a list of all the boards, analog and digital, listed in the
  # current configuration.
  # The fields to be exposed to the user are:
  #   - Real ID of the board in the config, not the one generated.
  #   - The display name of the board
  #   - The type of the board (analog in that case)
  #   - The model of the board (A200,A101,A102,etc.)
  #   - The number of interfaces
  #   - registered id (hidden field).
  @expose() # Ext.form.Action.load - expects JSON
  def getGridBoardsData(self, id):
    data = []
    # Append digital boards data
    for board in (model.currentConfig.get_boards().get_sangomaDigitalBoard() + \
      model.currentConfig.get_boards().get_sangomaAnalogBoard() + \
      model.currentConfig.get_boards().get_sangomaVirtualDigitalBoard()):

      boardModel = board.get_model() #get the board model
      boardType = model.boardsModelInfo[boardModel]['type']
      if boardType == 'digital':
        numIf = model.boardsModelInfo[boardModel]['numInterfaces']
      else:
        numIf = len(board.get_interface())
      data.append({
        'id': board.get_ID(),
        'displayName': board.get_displayName(),
        'type': boardType,
        'model': boardModel,
        'numInterfaces': numIf,
        'nodeId': model.getObjectId(board)
      })
    data = sorted(data, key=itemgetter('id'))
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

#################################################
#                                               #
# Interfaces methods (Add/delete/get/save)      #
#                                               #
#################################################
  ##########################################################################
  @expose()
  def addInterfaceFromEditor (self, **data):
    """Adds an interface to a board from the editor"""

    log.info("Adding interface: %s" % data)
    #TODO call the addInterface method of the model.

    return(str(extjs.FormActionSubmitResponse(success=True)))

  ##########################################################################
  @expose()
  def deleteInterfaceFromEditor (self, **data):
    """Delete an interface from a board from the editor"""

    log.info("Deleting interface: %s" % data)
    #TODO call the deleteInterface method of the model.

    return(str(extjs.FormActionSubmitResponse(success=True)))

  ##########################################################################
  # Returns the data for the interface associated to the given id.
  # The fields to be exposed to the user are:
  #   - the id of the interface entered in the config file 
  #   - The display name of the interface
  #   - The wanpipe number of this interface
  #   - registered id (hidden field).
  @expose() # Ext.form.Action.load - expects JSON
  def getFrmDigitalInterfaceData(self, id):
    # Get the instance of the interface
    interface =  model.getObjectFromEditorId(id)
    data = {
      'id': interface.get_ID(),
      'displayName': interface.get_displayName(),
      'wanpipe': interface.get_wanpipe(),
      'nodeId': id
    }             
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Returns the data for the interface associated to the given id.
  # The fields to be exposed to the user are:
  #   - the id of the interface entered in the config file 
  #   - The display name of the interface
  #   - The wanpipeInterface number of this interface
  #   - registered id (hidden field).
  @expose() # Ext.form.Action.load - expects JSON
  def getFrmAnalogInterfaceData(self, id):
    # Get the instance of the interface
    interface =  model.getObjectFromEditorId(id)
    data = {
      'id': interface.get_ID(),
      'displayName': interface.get_displayName(),
      'wanpipeInterface': interface.get_wanpipeInterface(),
      'nodeId': id
    }             
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Returns the data for the virutal digital interface associated to the 
  #   given id.
  # The fields to be exposed to the user are:
  #   - the id of the interface entered in the config file 
  #   - The display name of the interface
  #   - The peerVirtualInterfaceID of this interface
  #   - registered id (hidden field).
  @expose() # Ext.form.Action.load - expects JSON
  def getFrmVirtualDigitalInterfaceData(self, id):
    # Get the instance of the interface
    interface =  model.getObjectFromEditorId(id)
    data = {
      'id': interface.get_ID(),
      'displayName': interface.get_displayName(),
      'peerVirtualInterfaceID': interface.get_peerVirtualInterfaceID(),
      'nodeId': id
    }             
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Saves the modified informations of the interface.
  # Editable values are:
  #   - displayName
  #   - peerVirtualInterfaceID if it is a virtual board
  #   - wanpipeInterface if it is an analog board
  @expose()
  def saveInterfaces (self, **data):
    """Saves the modifications to an interface entered by the user in the editor"""
    log.info("Saving interface informations with data: %s" % data)

    #Decode received data
    interfaceData = simplejson.loads(data['interfaceInfo'])
    #Retrieve the corresponding instance for the board id
    interface = model.getObjectFromEditorId(interfaceData['nodeId'])
    #Reassign modified values
    model.saveAttributes(interface,interfaceData)

    #save the config afterward
    model.writeCurrentConfigToFile()

    return(str(extjs.FormActionSubmitResponse(success=True)))

  ##########################################################################
  # Returns a list of interface for the digital board's given id.
  # The fields to be exposed to the user are:
  #   - Real ID of the board in the config, not the one generated.
  #   - The display name of the board
  #   - The wanpipe number of this interface
  @expose() # Ext.form.Action.load - expects JSON
  def getGridDigitalInterfacesData(self, id):
    # Get the instance of the board
    board = model.getObjectFromEditorId(id)
    data = []

    for i in board.get_interface():
      data.append({
        'id': i.get_ID(),
        'displayName': i.get_displayName(),
        'wanpipe': i.get_wanpipe(),
        'nodeId': model.getObjectId(i)
      })
    data.sort()
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

  ##########################################################################
  # Returns a list of interface for the analog board's given id.
  # The fields to be exposed to the user are:
  #   - Real ID of the board in the config, not the one generated.
  #   - The display name of the board
  #   - The wanpipeInterface number of this interface
  @expose() # Ext.form.Action.load - expects JSON
  def getGridAnalogInterfacesData(self, id):
    # Get the instance of the board
    board = model.getObjectFromEditorId(id)
    data = []

    for i in board.get_interface():
      data.append({
        'id': i.get_ID(),
        'displayName': i.get_displayName(),
        'wanpipeInterface': i.get_wanpipeInterface(),
        'nodeId': model.getObjectId(i)
      })
    data.sort()
                 
    return(str(extjs.FormActionLoadResponse(success=True, data=data)))

