//-----------------------------------------------
// Add/Delete Physical Config methods
//-----------------------------------------------
Ext.namespace("Paraxip.config.physConfig");

var addPhysConfHandler = function(){
  alert("Feature not yet supported!");
};

function addConfig(){
  var form = addPhysConfForm.getForm();
  var el  = form.getEl();

  el.dom.action = "phys/addPhysicalConfigFromEditor";
  el.dom.method = 'POST';
  form.submit({
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      addPhysConfWindow.hide();
      //Ext.Msg.alert("Added config successfully!","Please configure the new configuration!");
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });
};

function removePhysConfig(){
  var selectedRecords = gridPhysicalConfig.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    if ( gridPhysicalConfig.store.getCount() - selectedRecords.length < 1 ){
      Ext.Msg.alert("Can not delete last config!",
        "At least one config is necessary for the system to work properly. " +
        "Please edit current config or create a new one before deleting " +
        "this one");
    } else {
      var physConfigs = new Array();
      for (var i = 0; i < selectedRecords.length; i++) {
        physConfigs.push(selectedRecords[i].data);
      }
      physConfigs = Ext.util.JSON.encode(physConfigs);
      Ext.Ajax.request({
        url: 'phys/deletePhysicalConfigFromEditor',
        method: 'POST',
        disableCaching: false,
        params: {"physConfigs":physConfigs},
        success: function ()
        {
          Paraxip.isConfigOutOfSynch(true);
          for (var index = 0; index < selectedRecords.length; index++) {
            gridPhysicalConfig.store.remove(selectedRecords[index]);
          }
          reloadTree(true);
        },
        failure: Paraxip.failureMessage
      });
    }
  }
};

var physConfTypeComboBox = new Ext.form.ComboBox({
  id              : 'configType',
  fieldLabel      : "Physical Config Type",
  store           : ['T1','E1','Analog'],
  helpText        : "pstnConfigphysicalInterfaceConfigs",
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  value           : 'T1',
  selectOnFocus   : true,
  width           : 100
});

var addPhysConfForm = new Ext.form.FormPanel({
  labelWidth  : 175,
  labelPad    : 10,
  region      : "center",
  bodyStyle   : 'padding:10px;',
  frame       : false,
  header      : false,
  footer      : false,
  id          : "addPhysConfForm",
  buttonAlign : "right",
  buttons     : [{
    id: "Paraxip.config.physConfig.addPhysConfButton",
    text: "Add",
    listeners: {'click':addConfig}
  },{
    id: "Paraxip.config.physConfig.cancelAddPhysConfButton",
    text: "Cancel",
    listeners: {'click':function(){addPhysConfWindow.hide();}}
  }]
});

var addPhysConfWindow = new Ext.Window({
  title       : 'Add Physical Config Window',
  layout      : 'border',
  width       : 505,
  height      : 150,
  closeAction : 'hide',
  plain       : true,
  id          : "addPhysConfWindow"
});

addPhysConfForm.add(physConfTypeComboBox);
addPhysConfWindow.add(addPhysConfForm);

var gridPhysicalConfig = new Ext.grid.GridPanel({
  title       : 'Physical Configurations Grid',
  id          : 'gridPhysicalConfig',
  autoScroll  : true,
  layout      : 'absolute',
  store       : new Ext.data.JsonStore({
    id:'storePhysicalConfig',
    url: 'phys/getGridPhysicalConfigData',
    root: 'data',
    fields: [
      {name: 'id'}, //Not displayed
      {name: 'displayName'},
      {name: 'nodeId'} //Not displayed
    ]
  }),
  columns     : [
    {header: "ID", width: 35, sortable: true, dataIndex: 'id',
      css:'padding:5px;'},
    {header: "Name", width: 200, sortable: true, dataIndex: 'displayName',
      css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

gridPhysicalConfig.addButton("Add Physical Config",
                             function(){addPhysConfWindow.show();});
gridPhysicalConfig.addButton("Remove Physical Config(s)",removePhysConfig);

gridPhysicalConfig.on('rowdblclick', function(grid, rowIndex){
  var record = grid.store.getAt(rowIndex);
  goToNode(record.get('nodeId'));
});

//------------------------------------------------
// Factory to create common fields between forms
//------------------------------------------------

/**************************
  AUDIO Configuration
***************************/

function createAudioLabel(){
  return new Ext.form.Label(Ext.apply({
    text  : "Audio Configuration",
    style : 'line-height:40px;'
  }));
};

function createPcmLawSelection(config){
  return new Ext.form.ComboBox( Ext.apply({
    fieldLabel      : "Default PCM law",
    name            : 'defaultPcmLaw',
    store           : ['PCMU','PCMA'],
    helpText        : "audioParametersaudiodefaultPcmLaw",
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  }, config));
};

// Max is 30 ms and Min is 10 ms
function createVoicePacketText(config){
  return new Ext.form.TextField( Ext.apply({
    fieldLabel  : "Voice packet length (ms)",
    name        : 'voicePacketLengthInMs',
    helpText    : "audioParametersaudiovoicePacketLengthInMs",
    width       : 162
  }, config));
};

function createToneSetAtributesSelection(config){
  return new Ext.form.ComboBox( Ext.apply({
    name            : 'toneSetName',
    fieldLabel      : "Tone Set Attributes",
    helpText        : 'toneSetAttributestoneSetName',
    store           : Paraxip.countryList,
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  }, config));
};


/********************************
  EchoCancellation Configuration
*********************************/

function createEchoCancelLabel(){
  return new Ext.form.Label(Ext.apply({
    text     : "Echo Cancellation",
    style    : 'line-height:40px;'
  }));
};

function createEcTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    helpText        : "HardwareEchoCancellationEchoCancellation",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createEcModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    helpText        : "HardwareEchoCancellationEchoCancellationmode",
    store           : ['NORMAL','SPEECH_RECOGNIZER_FRIENDLY','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 200,
    listeners       : {
      'select':echoCancellationDisabled
    }
  },config));
};

function createEcComfortNoiseSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'comfortNoiseMode',
    fieldLabel      : "Comfort Noise Mode",
    store           : ['NORMAL','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

// Max 896 Min 0
function createEcTailText(config){
  return new Ext.form.TextField(Ext.apply({
    name        : 'tailDisplacementInMs',
    fieldLabel  : "Tail Displacement (ms)",
    width       : 162
  },config));
};

function createEcDoubleTalkSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'doubleTalkBehavior',
    fieldLabel      : "Double Talk Behavior",
    store           : ['OPTIMAL','MORE_RESIDUAL_ECHO','MORE_CLIPPING'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

/****************************************
  AcousticEchoCancellation Configuration
*****************************************/

function createAcousticLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "Acoustic Echo Cancellation",
    style: 'line-height:40px;'
  }));
};

function createAecTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createAecModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['NORMAL','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

/***************************************
  LevelControl Configuration
****************************************/

function createLevelControlLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "Level Control",
    style: 'line-height:40px;'
  }));
};

function createLevelTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createLevelDirectionSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'direction',
    fieldLabel      : "Direction",
    store           : ['ALL','TO_PSTN','FROM_PSTN'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createLevelModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['MANUAL','AUTOMATIC','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

// Max 0 Min -40
function createLevelTargetText(config){
  return new Ext.form.TextField(Ext.apply({
    name        : 'targetLevelIndBM0',
    fieldLabel  : "Target Level In dBM0",
    allowBlank  : false,
    width       : 162
  },config));
};

// Max 24 Min -24
function createLevelGainText(config){
  return new Ext.form.TextField(Ext.apply({
    name        : 'gainIndB',
    fieldLabel  : "Gain In dB",
    width       : 162,
    allowBlank  : false,
    blankText   : "This field can not be empty"
  },config));
};

/****************************************************
  BackgroundNoiseAttenuation Configuration
*****************************************************/

function createBackgroundLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "Background Noise Attenuation",
    style: 'line-height:40px;'
  }));
};

function createBnaTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createBnaDirectionSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'direction',
    fieldLabel      : "Direction",
    store           : ['ALL','TO_PSTN','FROM_PSTN'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createBnaModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['ENABLED','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createBnaAttenuationSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'attenuationIndB',
    fieldLabel      : "Attenuation In dB",
    store           : ['-9','-12','-15','-18','-21','-24','-27','-30'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

/****************************************************
  DTMFRemoval Configuration
*****************************************************/

function createDTMFRemovalLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "DTMF Removal",
    style: 'line-height:40px;'
  }));
};

function createDtmfTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createDtmfDirectionSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'direction',
    fieldLabel      : "Direction",
    store           : ['FROM_PSTN'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createDtmfModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['ENABLED','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

//------------------------------------------------
// Common methods
//------------------------------------------------
function saveConfig(e){
  //e is the button clicked. To get the form, pass by its owner
  var owner = e.ownerCt;
  var form = owner.getForm();
  var el = form.getEl();

  el.dom.action = 'phys/savePhysicalConf';
  el.dom.method = 'POST';

  // getItemsValueAsJson is a Ext.Container override
  var physicalConfig = owner.getItemsValueAsJson();

  form.submit({
    params:{
      'physicalConfig': physicalConfig
    },
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });
};

function physConfCancel(){
  reloadTree(true);
};

/*
 * This method is used to show/hide the gainIndB and the targetLevelIndBMO fields
 * of the Physical Config forms according to the LevelControl/Mode attribute.
 * If mode is automatic, hide the field; if it's true, show the field.
 */
function levelControlVisibleFields(){
  var levelMode;
  var levelGain;
  var levelTargetIndBMO;

  if( this.id == "frmDigitalT1PhysConf" ) {
    levelMode = levelT1_mode_select;
    levelGain = levelT1_gainIndB_text;
    levelTargetIndBMO = levelT1_targetLevelIndBM0_text;
  } else if( this.id == "frmDigitalE1PhysConf" ) {
    levelMode = levelE1_mode_select;
    levelGain = levelE1_gainIndB_text;
    levelTargetIndBMO = levelE1_targetLevelIndBM0_text;
  } else if( this.id == "frmAnalogPhysConf" ) {
    levelMode = levelAnalog_mode_select;
    levelGain = levelAnalog_gainIndB_text;
    levelTargetIndBMO = levelAnalog_targetLevelIndBM0_text;
  } else {
    Paraxip.console.Error("The formPanel with id [%s] is unknown" % this.id);
    return;
  }
  if( levelMode.getValue() == "AUTOMATIC") {
    //levelGain.hide();
    //levelGain.getEl().up('.x-form-item').setDisplayed(false); //show label
    levelGain.disable();
    levelGain.clearInvalid();
    levelTargetIndBMO.enable();
  } else if( levelMode.getValue() == "MANUAL") {
    //levelGain.show();
    //levelGain.getEl().up('.x-form-item').setDisplayed(true); //show label
    levelGain.enable();
    levelTargetIndBMO.disable();
    levelTargetIndBMO.clearInvalid();
  } else if( levelMode.getValue() == "DISABLED") {
    levelGain.disable();
    levelGain.clearInvalid();
    levelTargetIndBMO.disable();
    levelTargetIndBMO.clearInvalid();
  }
};

function isDChannelEnabled(){
  var channelIndexText;
  var mtuText;

  if( this.getId() == "disableDChannelT1" ) {
    channelIndexText = channelT1_idx_text;
    mtuText = mtu_sizeT1_text;
  } else if( this.getId() == "disableDChannelE1" ) {
    channelIndexText = channelE1_idx_text;
    mtuText = mtu_sizeE1_text;
  }

  if( this.getValue() == "DISABLED" ) {
    channelIndexText.setContainerVisible(false);
    mtuText.setContainerVisible(false);
  } else if( this.getValue() == "ENABLED" ) {
    channelIndexText.setContainerVisible(true);
    channelIndexText.disable();
    mtuText.setContainerVisible(true);
  }
};

function echoCancellationDisabled(){
  var comfortNoiseMode;
  var tailDisplacementInMs;
  var doubleTalkBehavior;

  if( this.getId() == "ecT1_mode_selection" ) {
    comfortNoiseMode = ecT1_comfortNoiseMode_select;
    tailDisplacementInMs = ecT1_tailDisplacementInMs_text;
    doubleTalkBehavior = ecT1_doubleTalkBehavior_select;
  } else if( this.getId() == "ecE1_mode_selection" ) {
    comfortNoiseMode = ecE1_comfortNoiseMode_select;
    tailDisplacementInMs = ecE1_tailDisplacementInMs_text;
    doubleTalkBehavior = ecE1_doubleTalkBehavior_select;
  } else if( this.getId() == "ecAnalog_mode_selection" ) {
    comfortNoiseMode = ecAnalog_comfortNoiseMode_select;
    tailDisplacementInMs = ecAnalog_tailDisplacementInMs_text;
    doubleTalkBehavior = ecAnalog_doubleTalkBehavior_select;
  }

  if( this.getValue() == "DISABLED" ) {
    comfortNoiseMode.disable();
    tailDisplacementInMs.disable();
    doubleTalkBehavior.disable();
  } else {
    comfortNoiseMode.enable();
    tailDisplacementInMs.enable();
    doubleTalkBehavior.enable();
  }
};

//------------------------------------------------
// Apply_To forms and methods
//------------------------------------------------
function applyToConfig(e){
  var form = e.ownerCt;
  var url;
  var gridData;
  var records;
  var i;

  if( form.id == "assignBoardsWindow") {
    url = "phys/applyBoardsToConfig";
    records = assignedBoardsGrid.getStore().getRange();
    gridData = new Array();
    for (i = 0; i < records.length; i++) {
      gridData.push(records[i].data);
    }
    gridData = Ext.util.JSON.encode(gridData);
  } else if( form.id == "assignInterfacesWindow") {
    url = "phys/applyInterfacesToConfig";
    records = assignedInterfacesGrid.getStore().getRange();
    gridData = new Array();
    for (i = 0; i < records.length; i++) {
      gridData.push(records[i].data);
    }
    gridData = Ext.util.JSON.encode(gridData);
  }

  Ext.Ajax.request({
    url: url,
    method: 'POST',
    disableCaching: false,
    params: {'gridData':gridData,'configID':Ext.util.JSON.encode(configId)},
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      form.hide();
      //reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });

};

function addToGrid(e){
  var grid; //unassigned grid
  var assignedGrid;
  var i;

  if( e.id == "assignBoardButton" ) {
    grid = unassignedBoardsGrid;
    assignedGrid = assignedBoardsGrid;
  } else if( e.id == "assignInterfaceButton") {
    grid = unassignedInterfacesGrid;
    assignedGrid = assignedInterfacesGrid;
  }
  var selectedRecords = grid.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    assignedGrid.getStore().add(selectedRecords);
    for( i = 0; i < selectedRecords.length; i++ ) {
      grid.getStore().remove(selectedRecords[i]);
    }
  }

};

function removeFromGrid(e){
  var grid; //assigned grid
  var unassignedGrid;
  var i;

  if( e.id == "unassignBoardButton" ) {
    grid = assignedBoardsGrid;
    unassignedGrid = unassignedBoardsGrid;
  } else if( e.id == "unassignInterfaceButton") {
    grid = assignedInterfacesGrid;
    unassignedGrid = unassignedInterfacesGrid;
  }

  var selectedRecords = grid.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    unassignedGrid.getStore().add(selectedRecords);
    for( i = 0; i < selectedRecords.length; i++ ) {
      grid.getStore().remove(selectedRecords[i]);
    }
  }

};

//Analog configs
var configId = "";

var assignBoardsWindow = new Ext.Window({
  title       : 'Assign Boards To Config',
  layout      : 'border',
  width       : 600,
  height      : 500,
  closeAction : 'hide',
  resizable   : false,
  plain       : true,
  id          : "assignBoardsWindow",
  buttonAlign : "right",
  buttons     : [{
    id: "Paraxip.config.physConfig.saveAssignBoardsButton",
    text: "Save",
    listeners: {'click':applyToConfig}
  },{
    id: "Paraxip.config.physConfig.cancelAssignBoardsButton",
    text: "Cancel",
    listeners: {'click':function(){assignBoardsWindow.hide();}}
  }]
});

var assignBoardsForm = new Ext.FormPanel({
  region      : "center",
  id          : "assignBoardsForm",
  items       : [{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'assignBoardButton',
    text: '->',
    listeners: {'click':addToGrid}
  },{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'unassignBoardButton',
    text: '<-',
    listeners: {'click':removeFromGrid}
  }]
});

var unassignedBoardsGrid = new Ext.grid.GridPanel({
  title       : 'Unassigned Board(s)',
  id          : 'unassignedBoardsGrid',
  autoScroll  : true,
  region      : "west",
  width       : 270,
  store       : new Ext.data.JsonStore({
    id:'storeUnassignedBoards',
    url: 'phys/getUnassignedBoards',
    root: 'data',
    fields: [
      {name: 'id'},
      {name: 'displayName'}
    ]
  }),
  columns     :[
    {header: "ID", width: 35, sortable: true, dataIndex: 'id',
      css:'padding:5px;'},
    {header: "Board Name", width: 200, sortable: true, dataIndex: 'displayName',
      css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}

});

var assignedBoardsGrid = new Ext.grid.GridPanel({
  title       : 'Assigned Board(s)',
  id          : 'assignedBoardsGrid',
  region      : "east",
  autoScroll  : true,
  width       : 270,
  store       : new Ext.data.JsonStore({
    id:'storeAssignedBoards',
    url: 'phys/getAssignedBoards',
    root: 'data',
    fields: [
      {name: 'id'},
      {name: 'displayName'}
    ]
  }),
  columns     :[
    {header: "ID", width: 35, sortable: true, dataIndex: 'id',
      css:'padding:5px;'},
    {header: "Board Name", width: 200, sortable: true, dataIndex: 'displayName',
      css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}

});
assignBoardsWindow.add(assignBoardsForm);
assignBoardsWindow.add(assignedBoardsGrid);
assignBoardsWindow.add(unassignedBoardsGrid);

//Digital configs
var assignInterfacesWindow = new Ext.Window({
  title       : 'Assign Interfaces To Config',
  layout      : 'border',
  width       : 750,
  height      : 500,
  closeAction : 'hide',
  resizable   : false,
  plain       : true,
  id          : "assignInterfacesWindow",
  buttonAlign : "right",
  buttons     : [{
    id: "Paraxip.config.physConfig.saveAssignInterfaceButton",
    text: "Save",
    listeners: {'click':applyToConfig}
  },{
    id: "Paraxip.config.physConfig.cancelAssignInterfaceButton",
    text: "Cancel",
    listeners: {'click':function(){assignInterfacesWindow.hide();}}
  }]
});

var assignInterfacesForm = new Ext.Panel({
  labelWidth  : 175,
  labelPad    : 10,
  region      : "center",
  frame       : false,
  header      : false,
  footer      : false,
  id          : "assignInterfacesForm",
  items       : [{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'assignInterfaceButton',
    text: '->',
    listeners: {'click':addToGrid}
  },{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'unassignInterfaceButton',
    text: '<-',
    listeners: {'click':removeFromGrid}
  }]
});

var unassignedInterfacesGrid = new Ext.grid.GridPanel({
  title       : 'Unassigned Interface(s)',
  id          : 'unassignedInterfacesGrid',
  region      : "west",
  autoScroll  : true,
  width       : 345,
  store       : new Ext.data.JsonStore({
    id:'storeUnassignedInterfaces',
    url: 'phys/getUnassignedInterfaces',
    root: 'data',
    fields: [
      {name: 'displayName'},
      {name: 'boardID'},
      {name: 'ifName'},
      {name: 'id'}
    ]
  }),
  columns     : [
    {header: "Board Name", width: 130, sortable: true, dataIndex: 'displayName', css:'padding:5px;'},
    {header: "Board ID", width: 55, sortable: true, dataIndex: 'boardID', css:'padding:5px;'},
    {header: "Interface Name", width: 90, sortable: true, dataIndex: 'ifName', css:'padding:5px;'},
    {header: "Interface ID", width: 70, sortable: true, dataIndex: 'id', css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

var assignedInterfacesGrid = new Ext.grid.GridPanel({
  title       : 'Assigned Interface(s)',
  id          : 'assignedInterfacesGrid',
  region      : "east",
  autoScroll  : true,
  width       : 345,
  store       : new Ext.data.JsonStore({
    id:'storeAssignedInterfaces',
    url: 'phys/getAssignedInterfaces',
    root: 'data',
    fields: [
      {name: 'displayName'},
      {name: 'boardID'},
      {name: 'ifName'},
      {name: 'id'}
    ]
  }),
  columns     : [
    {header: "Board Name", width: 130, sortable: true, dataIndex: 'displayName', css:'padding:5px;'},
    {header: "Board ID", width: 55, sortable: true, dataIndex: 'boardID', css:'padding:5px;'},
    {header: "Interface Name", width: 90, sortable: true, dataIndex: 'ifName', css:'padding:5px;'},
    {header: "Interface ID", width: 70, sortable: true, dataIndex: 'id', css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

assignInterfacesWindow.add(assignInterfacesForm);
assignInterfacesWindow.add(assignedInterfacesGrid);
assignInterfacesWindow.add(unassignedInterfacesGrid);

