Ext.namespace("Paraxip.fileBrowser");

Paraxip.fileBrowser.lastClickedFile = new Ext.tree.TreeNode();
//Maximum size in bytes of a file for wich we will load its
//content in the browser.
Paraxip.fileBrowser.maximumLoadableFileSize = 256000 
Paraxip.fileBrowser.maximumUnloadableFileSize = 1048576 

Paraxip.fileBrowser.fileTree = new Ext.ux.FileTreePanel({
  id              : 'Paraxip.fileBrowser.fileTree',
  region          : 'west',
  width           : 225,
  minSize         : 250,
  maxSize         : 250,
  enableUpload    : false,
  enableNewDir    : false,
  enableDelete    : false,
  enableRename    : false,
  enableDD        : false,
  enableProgress  : false,
  autoScroll      : true,
  openMode        : 'download',
  //rootVisible     : false,
  rootText        : 'root',
  url             : '/fileBrowser/'
});

Paraxip.fileBrowser.getFileContent = function(node){
  if( node.attributes.leaf ) {
    Paraxip.fileBrowser.lastClickedFile = node;

    Ext.Ajax.request({
      url: "fileBrowser/getFileSize",
      params: {
        'filePath':node.getPath('text')
      },
      success: function(result){
         var response = Ext.util.JSON.decode(result.responseText);
         if( response.fileSize > Paraxip.fileBrowser.maximumUnloadableFileSize ) {
           Ext.Msg.alert("File size over 1MB", "The file you are about to open is over 1MB wich "+
                         "too big to be open in the browser. To see its content, please download "+
                         "the file on your computer.");
         } else if( response.fileSize <= Paraxip.fileBrowser.maximumUnloadableFileSize && response.fileSize >= Paraxip.fileBrowser.maximumLoadableFileSize ) {
           Ext.Msg.confirm("File size over 250KB", "The file you are about to open is over 250KB wich"+
                           " could cause a lag in the UI. Do you want to proceed?",
                           Paraxip.fileBrowser.showFileInBrowser);
         } else {
           Paraxip.fileBrowser.showFileInBrowser("yes");
         }
      }
    })
    
  }
}

Paraxip.fileBrowser.showFileInBrowser = function(openFile){
  if( openFile == "yes" ) {
    Ext.Ajax.request({
      url: "fileBrowser/showFileInBrowser",
      params: {
        'filePath':Paraxip.fileBrowser.lastClickedFile.getPath('text')
      },
      success: function(result){
        var response = Ext.util.JSON.decode(result.responseText);
        //Paraxip.fileBrowser.fileEditor.setDisabled(Paraxip.fileBrowser.lastClickedFile.disabled);
        Paraxip.fileBrowser.saveFile.setDisabled(Paraxip.fileBrowser.lastClickedFile.disabled);
        Paraxip.fileBrowser.clearChanges.setDisabled(Paraxip.fileBrowser.lastClickedFile.disabled);
        Paraxip.fileBrowser.fileEditor.setValue(response.fileText);
        Ext.getCmp("Paraxip.fileBrowser.description").setText("<html><br><br></html>", false);
        Ext.getCmp("Paraxip.fileBrowser.fileNameLabel").setText(
          "<html><br><h1><p align='center'>File: " + Paraxip.fileBrowser.lastClickedFile.getPath('text') 
          + "</p></h1></html>", false
        );
      },
      failure: Paraxip.failureMessage
    });
  }
}

Paraxip.fileBrowser.saveFileContent = function(){
  Ext.Ajax.request({
    url: "fileBrowser/saveFileChanges",
    params: {
      'filePath':Paraxip.fileBrowser.lastClickedFile.getPath('text'),
      'fileContent':Paraxip.fileBrowser.fileEditor.getValue()
    },
    success: function(){
       Ext.Msg.alert(Paraxip.fileBrowser.lastClickedFile.text + " saved!", 
                     "File saved successfully.");
    },
    failure: Paraxip.failureMessage
  });
}

Paraxip.fileBrowser.fileTree.on('click', Paraxip.fileBrowser.getFileContent);

Paraxip.fileBrowser.saveFile = new Ext.Button({
  id        : 'Paraxip.fileBrowser.saveFile',
  text      : 'Save Changes',
  minWidth  : 88,
  disabled  : true,
  listeners : {
    'click':Paraxip.fileBrowser.saveFileContent
  }
});

Paraxip.fileBrowser.clearChanges = new Ext.Button({
  id        : 'Paraxip.fileBrowser.clearChanges',
  text      : 'Clear Changes',
  minWidth  : 88,
  disabled  : true,
  listeners : {
    'click':function(){
      Paraxip.fileBrowser.getFileContent(Paraxip.fileBrowser.lastClickedFile);
    }
  }
});

Paraxip.fileBrowser.fileEditor = new Ext.form.TextArea({
  id      : 'Paraxip.fileBrowser.fileEditor',
  width   : 750,
  height  : 411
});

Paraxip.fileBrowser.fileEditorForm = new Ext.form.FormPanel({
  id      : 'Paraxip.fileBrowser.fileEditorForm',
  region  : 'center',
  items   : [{
    xtype:'label',
    id:'Paraxip.fileBrowser.description',
    html:"<html><p align='center'><br>This section of the webUI allows you to read " +
          "and edit configuration and logging files. Grayed out file name in the tree " +
          "means a read only files. It is possible to download files by right-clicking " +
          "on a file in the tree panel.</p></html>"
  },{
    xtype:'label',
    id:'Paraxip.fileBrowser.fileNameLabel',
    html:"<html><h1><p align='center'><br></p></h1></html>"
  },
    Paraxip.fileBrowser.fileEditor
  ],
  buttons : [
    Paraxip.fileBrowser.saveFile,
    Paraxip.fileBrowser.clearChanges
  ]
});

Paraxip.fileBrowser.fileBrowserTabPanel = new Ext.Panel({
  id        : 'Paraxip.fileBrowser.fileBrowserTabPanel',
  layout    : 'border',
  hideMode  : 'offsets',
  defaults  : {
    style: 'text-align:left',
    layout: 'fit'
  },
  items     : [
    Paraxip.fileBrowser.fileTree,
    Paraxip.fileBrowser.fileEditorForm
  ]
});
