/*
 * Paraxip Oam Common Library to Ext JS Library 2.2
 * Copyright(c) 2008, Paraxip Technologies
 */

Ext.namespace('Paraxip');

//List of supported countries
Paraxip.countryList = [
    'USA',
    'CANADA',
    'FCC',
    'TBR21',
    'ARGENTINA',
    'AUSTRALIA',
    'AUSTRIA',
    'BAHRAIN',
    'BELGIUM',
    'BRAZIL',
    'BULGARIA',
    'CHILE',
    'CHINA',
    'COLUMBIA',
    'CROATIA',
    'CYRPUS',
    'CZECH',
    'DENMARK',
    'ECUADOR',
    'EGYPT',
    'ELSALVADOR',
    'FINLAND',
    'FRANCE',
    'GERMANY',
    'GREECE',
    'GUAM',
    'HONGKONG',
    'HUNGARY',
    'ICELAND',
    'INDIA',
    'INDONESIA',
    'IRELAND',
    'ISRAEL',
    'ITALY',
    'JAPAN',
    'JORDAN',
    'KAZAKHSTAN',
    'KUWAIT',
    'LATVIA',
    'LEBANON',
    'LUXEMBOURG',
    'MACAO',
    'MALAYSIA',
    'MALTA',
    'MEXICO',
    'MOROCCO',
    'NETHERLANDS',
    'NEWZEALAND',
    'NIGERIA',
    'NORWAY',
    'OMAN',
    'PAKISTAN',
    'PERU',
    'PHILIPPINES',
    'POLAND',
    'PORTUGAL',
    'ROMANIA',
    'RUSSIA',
    'SAUDIARABIA',
    'SINGAPORE',
    'SLOVAKIA',
    'SLOVENIA',
    'SOUTHAFRICA',
    'SOUTHKOREA',
    'SPAIN',
    'SWEDEN',
    'SWITZERLAND',
    'SYRIA',
    'TAIWAN',
    'THAILAND',
    'UAE',
    'UK',
    'YEMEN'
  ]
/*
 * Those methods scans the boardGrid and for each board, test if it is an analog board,
 * a digital board or a virtual_digital board. Depending on the method, it returns true
 * if one of the boards matches the disired type. To test the board type, we use the 
 * isBoardAnalog, isBoardDigital and isBoardVirtualDigital methods.
 */
Paraxip.gridHasAnalogBoard = function(grid) {
  var records = grid.getStore().getRange();
  var board_type;

  if (records.length > 0) {
    for (var i = 0; i < records.length; i++) {
      board_type = records[i].get('model');
      if ( Paraxip.isBoardAnalog(board_type) ) {
        return true;
      }
    }
  }
  return false;
};

Paraxip.gridHasDigitalBoard = function(grid) {
  var records = grid.getStore().getRange();
  var board_type;

  if (records.length > 0) {
    for (var i = 0; i < records.length; i++) {
      board_type = records[i].get('model');
      if ( Paraxip.isBoardDigital(board_type) ) {
        return true;
      }
    }
  }
  return false;
};

Paraxip.gridHasVirtualDigitalBoard = function(grid) {
  var records = grid.getStore().getRange();
  var board_type;

  if (records.length > 0) {
    for (var i = 0; i < records.length; i++) {
      board_type = records[i].get('model');
      if ( Paraxip.isBoardVirtualDigital(board_type) ) {
        return true;
      }
    }
  }
  return false;
};

//If selected board is an A200 or an A400, it is analog.
Paraxip.isBoardAnalog = function(boardType) {
  return ( boardType == "A200" || boardType == "A400" );
};

// Digital boards starts with "A1"
Paraxip.isBoardDigital = function(boardType) {
  return (/^A1/).test(boardType);
};

Paraxip.isBoardVirtualDigital = function(boardType) {
  return (boardType == "VIRTUAL_DIGITAL");
};

//gateway status list
Paraxip.activeStatus = {
  id      : "Paraxip.activeStatus", 
  text    : "Gateway Status:  started",
  iconCls : ''
};

Paraxip.downStatus = {
  id      : "Paraxip.downStatus",
  text    : "Gateway Status:  stopped",
  iconCls : ''
};

Paraxip.workingStatus = {
  id    : "Paraxip.workingStatus",
  text  : "Gateway Status:  working"
};

Paraxip.isGwStartedCall = function() {
  //Paraxip.changeGwStatusBar(Paraxip.workingStatus, true, true);
  if( isGatewayInCLI ) {
    var url = 'status/pingGateway';
  } else {
    var url = 'status/isGatewayServiceStarted';
  }
  Ext.Ajax.request({
    url: url,
    method: 'POST',
    disableCaching: true,
    params: {js:Ext.util.JSON.encode('dummy param')},
    success: function (result)
    {
      var isGWStarted = Ext.util.JSON.decode(result.responseText).value;

      if( isGWStarted ) {
        Paraxip.changeGwStatusBar(Paraxip.activeStatus,isGWStarted,!isGWStarted);
      } else {
        Paraxip.changeGwStatusBar(Paraxip.downStatus,isGWStarted,!isGWStarted);
      }
    },
    failure: Paraxip.failureMessage
  });
};

/*
 * Change the Gateway Status: xxxx value in the status bar of the main panel
 * @param isStartDisabled: true if the start button should be grayed out; false if not;
 * @param isStopDisabled: true if the stop button should be grayed out; false if not;
 */
Paraxip.changeGwStatusBar = function(status, isStartDisabled, isStopDisabled) {
  if( !isGatewayInCLI ) {
    Paraxip.status.controls.startGwButton.setDisabled(isStartDisabled);
    Paraxip.status.controls.stopGwButton.setDisabled(isStopDisabled);
    Paraxip.status.controls.autoStartGW.setDisabled(false);
  }
  Ext.getCmp('Paraxip.status.controls.setRefreshTime').setDisabled(isStopDisabled);
  Ext.getCmp('Paraxip.status.controls.autoRefreshTime').setDisabled(isStopDisabled);
  Paraxip.status.statusTabPanel.getItem('systemStatusTabId').setDisabled(isStopDisabled);
  Paraxip.status.statusTabPanel.getItem('channelsTabId').setDisabled(isStopDisabled);
  Paraxip.config.routingRules.validate.setDisabled(isStopDisabled);

  if( isStartDisabled ) {
    Paraxip.status.controls.messagePanel.body.load({url:'/static/gateway_up.html',nocache:false});
  } else {
    Paraxip.status.controls.messagePanel.body.load({url:'/static/gateway_down.html',nocache:false});
  }

  if( status == Paraxip.workingStatus) {
    Ext.getCmp('gw_status_bar').showBusy(status);
  } else {
    Ext.getCmp('gw_status_bar').setStatus(status);
  }
};

/*
 * Change the status of the out of sync status bar to remind to the user he has
 * to restart the gateway in order to get the modifications made to the config
 * effective or if the modifications have been applied.
 * @param outOfSynch: true if the config is out of synch; false if not.
 */
Paraxip.isConfigOutOfSynch = function(outOfSynch) {
  Ext.Ajax.request({
    url: 'config/changeConfigOutOfSynch',
    method: 'POST',
    params: {newValue:outOfSynch}
  });
  if( outOfSynch ) {
    Paraxip.mainTabPanel.configSynchStatusBar.setStatus(Paraxip.mainTabPanel.outOfSynchText);
  } else {
    Paraxip.mainTabPanel.configSynchStatusBar.setStatus(Paraxip.mainTabPanel.synchText);
  }
}

/* 
 * Show a progress bar freezing all the ui until the request is finished.
 * @param msg: the message to display in the message window.
 */
Paraxip.showProgressBar = function(msg){
  Ext.MessageBox.show({
    msg: msg,
    progressText: 'Starting...',
    width:300,
    wait:true,
    waitConfig: {interval:200},
    //icon:'ext-mb-download', //custom class in msg-box.html
    animEl: 'mb7'
 })
}

/*
 * Hide the progress bar window showed with the method Paraxip.showProgressBar
 */
Paraxip.hideProgressBar = function(){
  Ext.MessageBox.hide();
}

/*
 * Display a pop-up message telling the user his last operation failed.
 */
Paraxip.failureMessage = function(){
  Ext.Msg.alert("Error!","Your last operation failed. Please contact support if the problem persist.");
};

/*
 * The following methods create all the elements that will, once put
 * together, form the Add Board Panel used in the wizard's hardware
 * configuration section and in the editor's boards section.
 */
Paraxip.createBoardSelectionComboBox = function(config){
  var board_init_value =  'A101';
  
  //Selection items
  var boardModels = ['A101','A102','A104','A108','A200'];
  if(offerVirtualBoards) {
    boardModels.push('VIRTUAL_DIGITAL');
  }
  return new Ext.form.ComboBox( Ext.apply({
    fieldLabel      : "Board Type",
    name            : "boardModel",
    store           : boardModels,
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    value           : board_init_value,
    selectOnFocus   : true,
    width           : 130
  },config));
};

Paraxip.showInterfaceNumberListener = function(analogIntfNum, virtualIntfNum){
  var selection = this.getValue();
  // "setContainerVisible" from paraxip_extjs_overrides.js
  analogIntfNum.setContainerVisible(Paraxip.isBoardAnalog(selection));
  virtualIntfNum.setContainerVisible(
    Paraxip.isBoardVirtualDigital(selection));
  return true;
}

Paraxip.createAnalogInterfaceNumComboBox = function(config){
  return new Ext.form.ComboBox( Ext.apply({
    fieldLabel      : "Number of Interfaces",
    name            : "interfaceNum",
    store           : [[2,'2'],[4,'4'],[8,'8'],[12,'12']],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    value           : 4,
    selectOnFocus   : true,
    width           : 130
  },config));
};

Paraxip.createVirtualInterfaceNumField = function(config){
  return new Ext.form.NumberField( Ext.apply({
    fieldLabel    : "Number of Virtual Interfaces (must be even)",
    disabled      : false,
    hidden        : true,
    name          : "interfaceNum",
    width         : 130,
    value         : 2,
    allowNegative : false,
    allowDecimals : false,
    allowBlank    : false,
    regex         : /[02468]$/, // Must be even
    regexText     : 'Must use an even number'
  },config));
};

Paraxip.createAddBoardPanel = function(config){
  return new Ext.form.FormPanel( Ext.apply({
    labelWidth  : 175,
    labelPad    : 10,
    bodyStyle   : 'padding:10px;',
    region      : 'center',
    frame       : false,
    header      : false,
    footer      : false,
    defaults    : {
      anchor: '75%'
    }
  },config));
}

/*
 * Creates a HashMap as the one in Java for Javascript.
 * Use as followed:
 *  var myMap = Paraxip.Map();
 *  key = 'xxxx';
 *  value = 'yyyy';
 *  myMap.put(key,value);
 *  myMap.get(key);
 */
Paraxip.Map = function()
{
    // members
    this.keyArray = new Array(); // Keys
    this.valArray = new Array(); // Values
        
    // methods
    this.put = put;
    this.get = get;
    this.size = size;  
    this.clear = clear;
    this.keySet = keySet;
    this.valSet = valSet;
    this.showMe = showMe;   // returns a string with all keys and values in map.
    this.findIt = findIt;
    this.remove = remove;
}

function put( key, val )
{
    var elementIndex = this.findIt( key );
    
    if( elementIndex == (-1) )
    {
        this.keyArray.push( key );
        this.valArray.push( val );
    }
    else
    {
        this.valArray[ elementIndex ] = val;
    }
}

function get( key )
{
    var result = null;
    var elementIndex = this.findIt( key );

    if( elementIndex != (-1) )
    {   
        result = this.valArray[ elementIndex ];
    }  
    
    return result;
}

function remove( key )
{
    var result = null;
    var elementIndex = this.findIt( key );

    if( elementIndex != (-1) )
    {
        this.keyArray = this.keyArray.removeAt(elementIndex);
        this.valArray = this.valArray.removeAt(elementIndex);
    }  
    
    return ;
}

function size()
{
    return (this.keyArray.length);  
}

function clear()
{
    for( var i = 0; i < this.keyArray.length; i++ )
    {
        this.keyArray.pop(); this.valArray.pop();   
    }
}

function keySet()
{
    return (this.keyArray);
}

function valSet()
{
    return (this.valArray);   
}

function showMe()
{
    var result = "";
    
    for( var i = 0; i < this.keyArray.length; i++ )
    {
        result += "Key: " + this.keyArray[ i ] + "\tValues: " + this.valArray[ i ] + "\n";
    }
    return result;
}

function findIt( key )
{
    var result = (-1);

    for( var i = 0; i < this.keyArray.length; i++ )
    {
        if( this.keyArray[ i ] == key )
        {
            result = i;
            break;
        }
    }
    return result;
}

function removeAt( index )
{
  var part1 = this.slice( 0, index);
  var part2 = this.slice( index+1 );

  return( part1.concat( part2 ) );
}

Array.prototype.removeAt = removeAt;

