//-----------------------------------------------
// Main form that contains all the fields
//-----------------------------------------------
Ext.namespace("Paraxip.wizard");

var hardware_form = new Ext.Panel({
  title     : "Hardware Configuration",
  layout    : 'border',
  frame     : true,
  hideMode  : 'offsets',
  header    : false,
  id        : "Paraxip.wizard.hardware_form",
  items     : [{
    xtype     : 'panel',
    region    : 'west',
    layout    : 'fit',
    margins   : '5 0 0 0',
    cmargins  : '5 5 0 0',
    width     : 120,
    height    : 400,
    minSize   : 120
  },{
    xtype     : 'panel',
    region    : 'east',
    layout    : 'fit',
    margins   : '5 0 0 0',
    cmargins  : '5 5 0 0',
    width     : 120,
    height    : 400,
    minSize   : 120
  }
  ]
});

// North panel: Simple description
var hwDescriptionPanel = new Ext.Panel ({  
  id      : 'Paraxip.wizard.descriptionPanel',
  region  : 'north',
  height  : 60,
  minSize : 60,
  items   : [{}]  
});

var hwDescriptionLabel = new Ext.form.Label({
  id      :  "Paraxip.wizard.descLabel",
  region  : 'north',  
  text    : "Add the telephony board(s) installed on your system to the following list:",
  style   : 'font-size:120%;font-weight:bold; line-height:60px;' 
});

hwDescriptionPanel.add(hwDescriptionLabel)

//Access variables and IDs last values
var gridIndex = 0;
var lastBoardID = 0;
var lastWanpipeNum = 0;
var isLastBoardAnalog = false;
var lastIntNumber = 0;

//Array containing the grid data to display to board added by the user
var boardData = [];

//Create a record type that will allow us to easily
//add data to our grid
DataRecord = Ext.data.Record.create([
  {name: 'board_id',type: 'int'},
  {name: 'model'},
  {name: 'num_interfaces', type: 'int'},
  {name: 'wanpipe', type: 'int'}
]);

//Associates the data values with the columns of the grid
var boardDataReader = new Ext.data.ArrayReader({}, DataRecord);

//Store that associates the data array
//to our array reader
var store = new Ext.data.Store({
  data: boardData,
  reader: boardDataReader
});

var clearHandler = function(){
  gridIndex = 0;
  lastBoardID = 0;
  lastWanpipeNum = 0;
  isLastBoardAnalog = false;
  lastIntNumber = 0;
};

store.on('clear', clearHandler);

//Grid to display added board
var grid = new Ext.grid.GridPanel({
  id      : 'Paraxip.wizard.board_display',
  layout  : 'fit',
  store   : store,
  region  : 'center',
  style   : 'text-align:left;',
  frame   : true,
  columns : [
    {id: 'boardID',header: "Board ID", width: 115, dataIndex: 'board_id',css:'padding:5px;'},
    {header: "Board Type", width: 115, dataIndex: 'model',css:'padding:5px;'},
    {header: "Number of Interfaces", width: 115, dataIndex: 'num_interfaces',css:'padding:5px;'},
    {header: "Wanpipe Number", width: 115, dataIndex: 'wanpipe',css:'padding:5px;'}
  ],
  enableColumnResize  : true,
  enableColumnMove    : false,
  enableHdMenu        : false,
  trackMouseOver      : true,
  stripeRows          : false,
  autoExpandColumn    : 'boardID', 
  sm: new Ext.grid.RowSelectionModel({singleSelect:true})
});

var board_type_select = Paraxip.createBoardSelectionComboBox({id: 'Paraxip.wizard.board_type_select'});

var interfaces_num = Paraxip.createAnalogInterfaceNumComboBox({id: 'Paraxip.wizard.interfaces_num'});

var interfaces_num_virtual_digital = Paraxip.createVirtualInterfaceNumField({id: 'Paraxip.wizard.interfaces_num_virtual_digital'});

board_type_select.on('select', Paraxip.showInterfaceNumberListener.createDelegate(board_type_select,[interfaces_num, interfaces_num_virtual_digital]));

//Return the number of interfaces on the board according to 
//its name.
var getDigitalBoardInterfacesNumber = function(boardType) {
  return parseInt(boardType.charAt(boardType.length - 1), 10);
};

var nextMsg = new Ext.form.Label({
  id      : "Paraxip.wizard.next_msg",
  region  : "south",
  layout  : 'fit',
  text    : "Click on the \"Next\" button to continue.",
  style   : 'font-size:100%;font-weight:bold; line-height:60px;text-align:right;padding-right:15;'
});

var optionsPanel = Paraxip.createAddBoardPanel({});

var optionsWindow = new Ext.Window({
  title       : 'Add Board Window',  
  layout      : 'border',
  width       : 505,
  height      : 150,
  closeAction : 'hide',
  plain       : true,
  id          : "Paraxip.wizard.options_window"
});

//Method called when the save button is clicked
var saveHandler = function() {
  var boardType = board_type_select.getValue();
  var isAnalog = Paraxip.isBoardAnalog(boardType);
  var isVirtualDigital = Paraxip.isBoardVirtualDigital(boardType);
  var interfacesNum;

  if (isAnalog) {
    interfacesNum = parseInt(interfaces_num.getRawValue(), 10);
  } else if (isVirtualDigital) {
    interfacesNum = parseInt(interfaces_num_virtual_digital.getRawValue(), 10);
  } else {
    interfacesNum = getDigitalBoardInterfacesNumber(boardType);
  }

  lastBoardID = lastBoardID + 1;

  if (lastWanpipeNum === 0) {
    lastWanpipeNum = 1;
  } else if (isLastBoardAnalog) {
    lastWanpipeNum = lastWanpipeNum + 1;
  } else {
    lastWanpipeNum = lastWanpipeNum + lastIntNumber;
  }

  lastIntNumber = interfacesNum;
  isLastBoardAnalog = isAnalog;

  var newRecord = new DataRecord({
    'board_id':lastBoardID,
    'model':boardType,
    'num_interfaces':interfacesNum,
    'wanpipe':lastWanpipeNum
  });

  store.add(newRecord);
  optionsWindow.hide();
};

var closeHandler = function(){
    optionsWindow.hide();
};

optionsWindow.add(optionsPanel);
optionsPanel.add(board_type_select);
optionsPanel.add(interfaces_num);
optionsPanel.add(interfaces_num_virtual_digital);

optionsPanel.addButton("Add", saveHandler, grid);
optionsPanel.addButton("Cancel", closeHandler, grid);

// Show only necessary fields once layout is done
optionsPanel.on('afterlayout', Paraxip.showInterfaceNumberListener.createDelegate(board_type_select,[interfaces_num, interfaces_num_virtual_digital]));

//Method called when the add button is clicked
var addHandler = function() { 
  optionsWindow.show(grid);
};

//When a board is removed, we need to decrease the id of every
//board currently in the board_data array
var reassignBoardId = function(e) {
  var newId = store.indexOf(e) + 1;
  e.set('board_id', newId);
};

// Reassing all the wanpipe numbers for each board. If the previous
// board is analog, the wanpipe number is increased by 1. If the previous
// board is digital, the wanpipe number is increased by the number 
// of interfaces that contains that previous board.
var reassignWanpipeNumber = function(e) {
  var index = store.indexOf(e);

  if (index === 0) {
    e.set('wanpipe', 1);
    lastWanpipeNum = 1;
  } else {
    if (isLastBoardAnalog) {
      lastWanpipeNum = lastWanpipeNum + 1;
    } else {
      lastWanpipeNum = lastWanpipeNum + lastIntNumber;
    }
    e.set('wanpipe', lastWanpipeNum);
  }

  lastIntNumber = e.get('num_interfaces');
  isLastBoardAnalog = Paraxip.isBoardAnalog(e.get('model'));

};

//Called when the remove button is clicked
var removeHandler = function() {
  var selectedRecord = grid.getSelectionModel().getSelected();

  if (selectedRecord !== undefined) {
    store.remove(selectedRecord);

    lastWanpipeNum = 0;
    lastIntNumber = 0;
    store.each(reassignBoardId);
    store.each(reassignWanpipeNumber);

    lastBoardID = lastBoardID - 1;
  }
};

grid.addButton("Add Board", addHandler, grid);
grid.addButton("Remove Board", removeHandler, grid);

hardware_form.add(hwDescriptionPanel);
hardware_form.add(grid);
hardware_form.add(nextMsg);



